@@ -2,6 +2,8 @@
 Copyright © 2025 John Liu
 """
 
+from dataclasses import dataclass
+
 PKG_NAME = "batch_img"
 VER = "version"
 EXPIRE_HOUR = 48
@@ -23,9 +25,13 @@ PATTERNS = (
 )
 REPLACE = "replace"
 EXIF = "exif"
+
+
 # Resize to 1920-pixel max length
 # Add 5-pixel width black color border
 # Remove GPS location info
-MAX_LENGTH = 1920
-BD_WIDTH = 5
-BD_COLOR = "black"
+@dataclass(frozen=True)  # immutable data
+class Conf:
+    max_length: int = 1920
+    bd_width: int = 5
+    bd_color: str = "black"
